@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Calc::Worker;
-$Bot::Cobalt::Plugin::Calc::Worker::VERSION = '0.004004';
+$Bot::Cobalt::Plugin::Calc::Worker::VERSION = '0.004005';
 use strict;
 use bytes;
 
@@ -28,9 +28,11 @@ sub worker {
  
   # not error-checked, may fail silently on some platforms ..
   # (OpenBSD lacks RLIMIT_AS f.ex)
-  setrlimit RLIMIT_CPU, 10, 10;
-  for my $const (RLIMIT_DATA RLIMIT_STACK RLIMIT_AS RLIMIT_VMEM) {
-    eval {; setrlimit $const, MEMLIMIT_BYTES, MEMLIMIT_BYTES };
+  { local $SIG{__WARN__} = sub {};
+    eval {; setrlimit RLIMIT_CPU, 10, 10 };
+    for my $const (RLIMIT_DATA RLIMIT_STACK RLIMIT_AS RLIMIT_VMEM) {
+      eval {; setrlimit $const, MEMLIMIT_BYTES, MEMLIMIT_BYTES };
+    }
   }
 
   my ($buf, $read_bytes) = '';
